<template>
    <MenuReaction v-if="isShowReaction && showEmoji && status !== 'failed'" :id="id" :is-seller="isSeller" @onSuccess="handleReactionSuccess" @onActive="handleOnActive"/>
    <span v-html="message" class="overflow-hidden relative block break-words"></span>
    <ReactionIcon :reaction-list="reactions"/>
    <FailedSendMessage v-if="isSeller && status ==='failed'" :message="wa_error_message"/>
    <div v-if="is_forwarded === 1" class="absolute  -top-8 gap-1 rounded-tl-xl rounded-tr-xl left-0 block w-full  mt-4">
      <div class="relative flex py-2 items-center">
        <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 fill-current text-gray-400" viewBox="0 0 24 24"><path d="M21,12L14,5V9C7,10 4,15 3,20C5.5,16.5 9,14.9 14,14.9V19L21,12Z" /></svg>
        <span class="italic text-gray-400">Forwarded</span>
      </div>
    </div>

    <div :class="`relative flex items-end gap-5 ${assignee ? 'justify-between' : 'justify-end'}` ">
      <div v-if="isFromApplication && isSeller" class="flex items-center gap-2 whitespace-nowrap  rounded-full py-1 px-2 bottom-1 text-xs bg-white text-primary text-right select-none">
        <span class="w-2 h-2 bg-scheme-primary rounded-full"></span>
        <span>{{ applicationAgentName }}</span>
      </div>
      <div v-else-if="assignee"
            class="flex items-center gap-2 whitespace-nowrap  rounded-full py-1 px-2 bottom-1 text-xs bg-white text-primary text-right select-none">
        <span class="w-2 h-2 bg-scheme-primary rounded-full"></span>
        <span>{{ assignee.full_name }}</span>
      </div>
      <div class="flex gap-1 items-center justify-end">
        <span class="block  text-xs text-gray-600 text-right select-none">{{ date }}</span>
        <!-- loading -->
        <template v-if="isSeller && !isLoader">
          <IcMessageStatus :status="status"/>
        </template>
      </div>
    </div>
    <div class="relative block pt-2 w-full border-t border-scheme-primary mt-2 border-opacity-10 text-center">
      <button @click="openDialog" class="btn !h-8 min-h-0 btn-link !no-underline rounded-0 normal-case relative block w-full font-medium text-sm text-scheme-primary" v-if="buttonLabel">{{buttonLabel}}</button>
    </div>
<!--  <div-->
<!--      :class="`relative flex gap-4 w-full ${isLoader ? 'animate-pulse': ''}  ${isSeller ? 'flex-row-reverse' : 'flex-row'}`">-->
<!--    <div-->
<!--        :class="`relative overflow-hidden w-14 h-14 ${isLoader ? 'bg-gray-400': 'bg-white shadow-md'}  rounded-full flex items-center ${isSeller ? 'order-2 p-2 ' : 'p-4 order-1'}`">-->
<!--      <div v-if="!isLoader" class="">-->
<!--        <ic-person-general />-->
<!--      </div>-->
<!--      &lt;!&ndash;        <Avatar :url="'https://source.unsplash.com/random/150x150/?avatar'"/>&ndash;&gt;-->
<!--    </div>-->
<!--    <div-->
<!--        :class="`relative max-w-1/3 min-w-1/4 w-auto mb-12 overflow-hidden shadow-sm  ${isSeller ? 'chat-right order-2 ' : 'chat-left order-1 '} ${isLoader ? 'bg-gray-300': ''}`">-->
<!--      <div :class="`relative block w-full  ${isSeller ? 'bg-scheme-primary bg-opacity-20 chat-right' : ' bg-gray-100 chat-left'} ${isLoader ? 'bg-gray-300': ''}`">-->
<!--        <div class="relative block py-2 pl-2 pr-6">-->
<!--          <div class="relative inline-block overflow-hidden text-base whitespace-normal pb-2 text-gray-800" v-html="message">-->
<!--          </div>-->
<!--          <div class="flex gap-1 items-center justify-end absolute right-2 bottom-1">-->
<!--            <span class="block  text-xs text-gray-600 text-right select-none">{{ date }}</span>-->
<!--            &lt;!&ndash; loading &ndash;&gt;-->
<!--            <template v-if="isSeller && !isLoader">-->
<!--              <IcMessageStatus :status="status"/>-->
<!--            </template>-->
<!--          </div>-->
<!--        </div>-->
<!--        <div class="relative block w-full border-t border-scheme-primary border-opacity-10 text-center">-->
<!--          <button class="btn btn-link !no-underline rounded-0 normal-case relative block w-full py-1 font-medium text-sm text-scheme-primary" v-if="buttonLabel">{{buttonLabel}}</button>-->
<!--        </div>-->
<!--      </div>-->
<!--    </div>-->
<!--  </div>-->
</template>

<script setup lang="ts">

import Avatar from "../Avatar/Avatar.vue";
import IcPersonGeneral from "../Icon/IcPersonGeneral.vue";
import IcMessageStatus from "../Icon/IcMessageStatus.vue";
import FailedSendMessage from "../Utility/FailedSendMessage.vue";
import {useGeneralStore} from "../../stores/general";
import ReactionIcon from "../Icon/ReactionIcon.vue";
import ChatRepliedMessage from "./ChatRepliedMessage.vue";
import MenuReaction from "../../components/Menu/MenuReaction.vue";
import {onMounted, ref, watch} from "vue";
import {useChatListStore} from "../../stores/chat_list";

const general = useGeneralStore()
const emit = defineEmits(["onClick"])
interface Props {
  isSeller?: boolean
  isLoader?: boolean
  isShowReaction?: boolean
  is_forwarded?: number
  date?: string
  assignee?:  {
    full_name?: string
  }
  message?: string
  id?: bigint
  wa_error_message?: string
  chatType?: string
  status?: string
  object?: any
  reactions?: any
  buttonLabel?: string|null
  isFromApplication: boolean | null
  applicationAgentName: string | null
}
let props = withDefaults(defineProps<Props>(), {
  isSeller: false,
  isLoader: false,
  isShowReaction: true,
  is_forwarded: 0,
  id: null,
  date: null,
  buttonLabel: null,
  assignee: null,
  chatType: null,
  wa_error_message: null,
  status: 'sent',
  message: null,
  reactions: [],
  object: {
    list: []
  },
  isFromApplication: null,
  applicationAgentName: null,
});

const chat = useChatListStore()
const showEmoji = ref(false)
const emojiActive = ref(false)
const reactionArr = ref([])

const handleReactionSuccess = (emojiString: any) => {
  let type_chat = general.chatTab
  let platform = ''

  if(general.chatTab === 'instagram'){
    type_chat = 'instagram'

    if(chat.selectedChatType === 'instagram'){
      platform = 'instagram'
    }
    
    if(chat.selectedChatType === 'facebook'){
      platform = 'page'
    }
  }

  chat.sendEmoji(chat.selectedChat, {
    to: chat?.detail?.customer?.phone,
    chat_id: props.id,
    emoji: emojiString,
    platform: platform
  },type_chat).then((resp) => {
    if (resp.code === 200) {
      const currentReaction = reactionArr.value.findIndex((rc) => rc.chat_id === props.id && rc.from_chat_user_id === chat.selectedChat)
      if (currentReaction == -1 && reactionArr.value.length == 0) {
        reactionArr.value.push({
          chat_id : props?.id,
          from_chat_user_id: chat.selectedChat,
          value: emojiString
        })
      } else {

        reactionArr.value.splice(currentReaction,1, {
          chat_id : props?.id,
          from_chat_user_id: chat.selectedChat,
          value: emojiString
        })
      }
    } else {
      console.log("400")
    }
  })
}

const handleOnActive= (event) => {
  emojiActive.value = event
}

onMounted(() => {
  reactionArr.value = props.reactions
})

watch(() => props.reactions, (val) => {
  reactionArr.value = val
})

const openDialog = () => {

    if ((props.buttonLabel).toLowerCase() === "pilih pembayaran") {
        const object = {
            value: props.buttonLabel,
            child:props.object.list
        }
        emit("onClick", object)
    } else {
        const object = props.object.list.length > 0 ? props.object.list[0] : []
        emit("onClick", object)
    }
}
</script>
